/// <reference types="react" />
import * as React from 'react';
export declare function yupToFormErrors(yupError: any): FormikErrors;
export declare function touchAllFields<T>(fields: T): {
    [field: string]: boolean;
};
export declare function validateFormData<T>(data: T, schema: any): Promise<void>;
export interface FormikValues {
    [field: string]: any;
}
export interface FormikErrors {
    [field: string]: string;
}
export interface FormikTouched {
    [field: string]: boolean;
}
export interface FormikConfig<Props, Values, Payload> {
    displayName?: string;
    mapPropsToValues?: (props: Props) => Values;
    mapValuesToPayload?: (values: Values) => Payload;
    validationSchema: any;
    handleSubmit: (payload: Payload, formikBag: FormikBag<Props, Values>) => void;
}
export interface FormikState<V> {
    values: V;
    error?: any;
    errors: FormikErrors;
    touched: FormikTouched;
    isSubmitting: boolean;
}
export interface FormikActions<P, V> {
    setError: (e: any) => void;
    setErrors: (errors: FormikErrors) => void;
    setSubmitting: (isSubmitting: boolean) => void;
    setTouched: (touched: FormikTouched) => void;
    setValues: (values: V) => void;
    resetForm: (nextProps?: P) => void;
}
export interface FormikHandlers {
    handleSubmit: (e: React.FormEvent<HTMLFormElement>) => void;
    handleChange: (e: React.ChangeEvent<any>) => void;
    handleBlur: (e: any) => void;
    handleChangeValue: (name: string, value: any) => void;
    handleReset: () => void;
}
export declare type InjectedFormikProps<Props, Values> = Props & FormikState<Values> & FormikActions<Props, Values> & FormikHandlers;
export declare type FormikBag<P, V> = {
    props: P;
} & FormikActions<P, V>;
export declare type CompositeComponent<P> = React.ComponentClass<P> | React.StatelessComponent<P>;
export interface ComponentDecorator<TOwnProps, TMergedProps> {
    (component: CompositeComponent<TMergedProps>): React.ComponentClass<TOwnProps>;
}
export interface InferableComponentDecorator<TOwnProps> {
    <T extends CompositeComponent<TOwnProps>>(component: T): T;
}
export declare function Formik<Props, Values extends FormikValues, Payload>({displayName, mapPropsToValues, mapValuesToPayload, validationSchema, handleSubmit}: FormikConfig<Props, Values, Payload>): ComponentDecorator<Props, InjectedFormikProps<Props, Values>>;
